@@ -13,7 +13,7 @@ plot.tscgm.ar2 <- function(x, mat=c("precision","autoregression1",
    }
  else if (mat == "autoregression1") {
       autoR1 <- x$gamma[1:p,] 
-      nw_full <- network(autoR1)
+      nw_full <- network(autoR1, loops=TRUE)
       plot.network(nw_full,label = network.vertex.names(nw_full), 
         usearrows = TRUE,
         displayisolates = FALSE,...)
@@ -22,9 +22,9 @@ else if (mat == "autoregression2") {
         d1= p + 1
         d2= 2* p
         autoR2 <- x$gamma[d1:d2,] 
-        nw_full <- network(autoR2)
+        nw_full <- network(autoR2, loops=TRUE)
       plot.network(nw_full,label = network.vertex.names(nw_full), 
         usearrows = TRUE,
-        displayisolates = FALSE,...)
+        displayisolates = FALSE, ...)
         }
 }
\ No newline at end of file
